'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global STATS, log */

// Log a message on GAB log server. The user's userid will be prepended to the
// message.
// If callback() is specified, call callback() after logging has completed
const sendMessageToLogServer = function (fullUrl, callback) {
  if (!fullUrl) {
    return;
  }

  $.ajax({
    jsonp: false,
    type: 'GET',
    url: fullUrl,
    success() {
      if (typeof callback === 'function') {
        callback();
      }
    },
    error(e) {
      log('message server returned error: ', e.status);
    },
  });
};

// Log a message on GAB log server. The user's userid will be prepended to the
// message.
// If callback() is specified, call callback() after logging has completed
const recordMessageWithUserID = function (msg, queryType, callback) {
  if (!msg || !queryType) {
    return;
  }

  // Include user ID in message
  const fullUrl = `https://log.getadblock.com/record_log.php?type=${queryType}&message=${encodeURIComponent(`${STATS.userId()} f:${STATS.flavor} o:${STATS.os} ${msg}`)}`;
  sendMessageToLogServer(fullUrl, callback);
};

// Log a message on GAB log server.
// If callback() is specified, call callback() after logging has completed
const recordAnonymousMessage = function (msg, queryType, callback) {
  if (!msg || !queryType) {
    return;
  }

  // Include user ID in message
  const fullUrl = `https://log.getadblock.com/record_log.php?type=${queryType}&message=${encodeURIComponent(msg)}`;
  sendMessageToLogServer(fullUrl, callback);
};

// Log an 'error' message on GAB log server.
/* exported recordErrorMessage */
const recordErrorMessage = function (msg, callback) {
  recordMessageWithUserID(msg, 'error', callback);
};

// Log an 'status' related message on GAB log server.
/* exported recordStatusMessage */
const recordStatusMessage = function (msg, callback) {
  recordMessageWithUserID(msg, 'stats', callback);
};

// Log a 'general' message on GAB log server.
/* exported recordGeneralMessage */
const recordGeneralMessage = function (msg, callback) {
  recordMessageWithUserID(msg, 'general', callback);
};

// Log an 'adreport' related message on GAB log server.
/* exported recordAdreportMessage */
const recordAdreportMessage = function (msg) {
  recordMessageWithUserID(msg, 'adreport');
};

// Log an 'surveys' related message on GAB log server.
/* exported recordSurveysMessage */
const recordSurveysMessage = function (msg) {
  recordMessageWithUserID(msg, 'surveys');
};

Object.assign(window, {
  recordErrorMessage,
  recordStatusMessage,
  recordGeneralMessage,
  recordAdreportMessage,
  recordSurveysMessage,
  recordMessageWithUserID,
  recordAnonymousMessage,
});
